%function[] = DCTIF_demo()
% Demo - Discrete Cosine Transform based Image Fusion Techniques  
% Developed by: Dr. VPS Naidu, MSDF Lab
% Ref:- Discrete Cosine Transform based Image Fusion Techniques, 
%       Journal of Communication, Navigation and Signal Processing (Jan.12)
%       Vol.1, No.1, pp.35-45
% Paper at: http://nal-ir.nal.res.in/10440/1/7_Discrete_Cosine_Transform_based_Image_Fusion_Techniques.pdf
close all;
clear all;
home;
flg = 1; % 1: display the results & 0: no display

% Reference image (ground truth)
imt = double(imread('saras9t.jpg'));

% images to be fused
im1 = double(imread('saras91.jpg'));
im2 = double(imread('saras92.jpg'));

if flg == 1
    figure(1); imshow(im1,[]);
    figure(2); imshow(im2,[]);
    pause(1);
end

h = waitbar(0,'Please wait...');
bs = [2 4 8 16 32 64 128 256 512]; %block size
lbs = length(bs);
for i=1:lbs
    DCTav = DCTIFav(im1,im2,bs(i)); %eq.5
    waitbar((i-0.9)/lbs);
    
    DCTma = DCTIFmax(im1,im2,bs(i)); %eq.6
    waitbar((i-0.65)/lbs);
    
    DCTah = DCTIFah(im1,im2,bs(i)); %eq.7
    waitbar((i-0.55)/lbs);
    
    DCTe = DCTIFek(im1,im2,bs(i)); %eq.10
    waitbar((i-0.4)/lbs);
    
    DCTch = DCTIFb(im1,im2,bs(i)); %eq.9
    waitbar((i-0.2)/lbs);
    
    DCTcm = DCTIFwb(im1,im2,bs(i)); %eq.8
    waitbar(i/lbs);
    
    %Display results
    if flg == 1
        figure(i+2);
        subplot(421); imshow(imfav,[]);     
        imd = imt-imfav;
        subplot(422); imshow(imd,[]);
        subplot(423); imshow(imfe,[]);     
        imd = imt-imfe;
        subplot(424); imshow(imd,[]);
        subplot(425); imshow(imfb,[]);     
        imd = imt-imfb;
        subplot(426); imshow(imd,[]);
        subplot(427); imshow(imfwb,[]);     
        imd = imt-imfwb;
        subplot(428); imshow(imd,[]);  
        pause(0.2);
    end
end
close(h);
